# pipeline demo

- source data (text,url,audio,video,pdf) ----extract----> text ----llm promt instruct task(extract,summary,keyword,knowledge_graph,classify) ----instructor(tools,json)--> video chapter script (role relationship)

> [!TIP]
> if llm support all rich text and MultiModal data with instruct prompt, input tokens embedding with long context and Generative output tokens all rich text and MultiModal data, it a big bang~!!!!!!!! KISS~, just use human language is ok~ (maybe bot can self learning your action like a baby grow up)
> **Yours. Truly. :)**

# prompt is all u need
- **https://www.promptingguide.ai/**
- **https://platform.openai.com/docs/guides/prompt-engineering**
- https://python.useinstructor.com/prompting/
- **https://github.com/MadcowD/ell**
- https://github.com/microsoft/prompt-engine
- https://smith.langchain.com/hub

# TODO
- [ ] sink to db, auto admin dashboard
  

# License
<a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-nc-nd/4.0/88x31.png" /></a><br />This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/4.0/">Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International License</a> @weedge(weege007@gmail.com)